@@ -2,9 +2,22 @@ import numpy as np
 import pandas as pd
 
 
-#make function to read .csv file and return dataframe
+#make function to read .csv file print time taken to read and return dataframe
 def leggi_csv(file_name):
+    import time
+    start = time.time()
     df = pd.read_csv(file_name)
+    end = time.time()
+    print("Tempo impiegato per leggere il file: ", end-start)
+    return df
+
+#make function to read feather file and return dataframe and print time taken to read
+def leggi_feather(file_name):  
+    import time
+    start = time.time()
+    df = pd.read_feather(file_name)
+    end = time.time()
+    print("Tempo impiegato per leggere il file: ", end-start)
     return df
 
 #make function to read excel file and return dataframe
@@ -12,7 +25,6 @@ def leggi_xls(file_name):
     df = pd.read_excel(file_name)
     return df
 
-
 #make function to readspecific sheet from excel file and return dataframe
 def leggi_sheet(file_name, sheet_name):
     df = pd.read_excel(file_name, sheet_name)
@@ -65,5 +77,15 @@ def rimuovi_colonna(df, colonna):
 def rimuovi_colonne(df, colonne):
     return(df.drop(colonne, axis=1))
 
+#make function to return dataframe with list columns passed
+def seleziona_colonne(df, lista_colonne):
+    return(df[lista_colonne])
+
+#make function to apply sql query on dataframe
+def esegui_query(df, query):
+    return(df.query(query))
+
+
+
 
 
